@@ -272,22 +272,60 @@ BOOST_PYTHON_MODULE (gfal2)
         )
         .def("cancel", &PyGfal2::Gfal2Context::cancel,
             "Cancel running operations")
-        .def("bring_online", &PyGfal2::Gfal2Context::bring_online,
+        .def("bring_online",
+            static_cast<boost::python::tuple (PyGfal2::Gfal2Context::*)(
+                const std::string& path, time_t pintime,
+                time_t timeout, bool async)>(&PyGfal2::Gfal2Context::bring_online),
+            "Performs a bring online operation (only for protocols that support this operation)"
+        )
+        .def("bring_online",
+            static_cast<boost::python::tuple (PyGfal2::Gfal2Context::*)(
+                const std::string& path, const std::string& metadata, time_t pintime,
+                time_t timeout, bool async)>(&PyGfal2::Gfal2Context::bring_online),
             "Performs a bring online operation (only for protocols that support this operation)"
         )
         .def("bring_online_poll", &PyGfal2::Gfal2Context::bring_online_poll,
             "Polls the status for asynchronous bring_online operations"
         )
-        .def("release", &PyGfal2::Gfal2Context::release,
+        .def("archive_poll", &PyGfal2::Gfal2Context::archive_poll,
+            "Polls the status for asynchronous archive operations"
+        )
+        .def("release",
+            static_cast<int (PyGfal2::Gfal2Context::*)(
+                const std::string &)>(&PyGfal2::Gfal2Context::release),
+            "Shortcut for release(path, token = '')"
+        )
+        .def("release",
+            static_cast<int (PyGfal2::Gfal2Context::*)(const std::string& path,
+                const std::string& token)>(&PyGfal2::Gfal2Context::release),
             "Releases a file pinned by a bring_online call"
         )
-        .def("bring_online", &PyGfal2::Gfal2Context::bring_online_list,
-            "Performs a bulk bring online operation"
+        .def("bring_online",
+            static_cast<boost::python::tuple (PyGfal2::Gfal2Context::*)(
+                const boost::python::list& files, time_t pintime,
+                time_t timeout, bool async)>(&PyGfal2::Gfal2Context::bring_online_list),
+            "Performs a bring online operation (only for protocols that support this operation)"
+        )
+        .def("bring_online",
+            static_cast<boost::python::tuple (PyGfal2::Gfal2Context::*)(
+                const boost::python::list& files, const boost::python::list& metadata, time_t pintime,
+                time_t timeout, bool async)>(&PyGfal2::Gfal2Context::bring_online_list),
+            "Performs a bring online operation (only for protocols that support this operation)"
         )
         .def("bring_online_poll", &PyGfal2::Gfal2Context::bring_online_poll_list,
             "Performs a bulk bring online poll operation"
         )
-        .def("release", &PyGfal2::Gfal2Context::release_list,
+        .def("archive_poll", &PyGfal2::Gfal2Context::archive_poll_list,
+            "Performs a bulk archive poll operation"
+        )
+        .def("release",
+            static_cast<boost::python::list (PyGfal2::Gfal2Context::*)(
+                const boost::python::list &)>(&PyGfal2::Gfal2Context::release_list),
+            "Shortcut for release (paths[], token = '')"
+        )
+        .def("release",
+            static_cast<boost::python::list (PyGfal2::Gfal2Context::*)(
+                const boost::python::list& files, const std::string& token)>(&PyGfal2::Gfal2Context::release_list),
             "Releases a set of files pinned by a bring_online call"
         )
         .def("abort_bring_online", &PyGfal2::Gfal2Context::abort_bring_online,
@@ -402,6 +440,10 @@ BOOST_PYTHON_MODULE (gfal2)
             &PyGfal2::GfaltParams::set_proxy_delegation,
             "Enable or disable TPC with proxy delegation (default enabled)"
         )
+        .add_property("evict", &PyGfal2::GfaltParams::get_evict,
+            &PyGfal2::GfaltParams::set_evict,
+            "Enable or disable source file eviction from disk buffer when the transfer is finished"
+        )
         .add_property("local_transfers", &PyGfal2::GfaltParams::get_local_transfers,
             &PyGfal2::GfaltParams::set_local_transfers,
             "Permission flag to enable or disable transfers via local streaming (default enabled)"
